@@ -13,12 +13,12 @@ DBIx::Class::Result::Validation - DBIx::Class component to manage validation on
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -104,8 +104,6 @@ sub validate {
   my $self = shift;
   $self->_erase_result_error();
   $self->_validate();
-  use Data::Dumper 'Dumper';
-  print Dumper $self->result_errors;
   return 0 if (defined $self->result_errors);
   return 1;
 };
